@@ -15,6 +15,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *----------------------------------------------------------------------------
+ * Version 1.8
+ *   - Fix crash with certain frame size (unaligned buffer used with SSE2)
+ *
  * Version 1.7
  *   - Terminate using exit/return instead of abort (no more "crashes")
  *
@@ -662,6 +665,7 @@ int main (int argc, char *argv[])
 	/* align buffers */
 	in_img  = in_img + (16 - ((int)in_img % 16));
 	old_img = old_img + (16 - ((int)old_img % 16));
+	out_buf = out_buf + (16 - ((int)out_buf % 16));
 
 	/* get frame number */
 	frames  = get_frame_total_avis(avis_hnd);
